#pragma once

using namespace System;


namespace TechnoAP { namespace usbmca {
	
	using namespace TechnoAP::usbmca;

	namespace constant
	{
		/////Unit Class/////
		/// <summary>
		/// Summary for Unit
		/// </summary>
		public ref class Unit
		{
		public:
			const static __int64 CountPerDigitNsec = 40;   // count/digit(nsec)

		};

		/////Unit Class/////
		/// <summary>
		/// Summary for Command
		/// </summary>
		public ref class Command
		{
		public:
			// A single command
			const static String ^MODW = "MODW";      // measurement mode(histogram or list)
			const static String ^MMDW = "MMDW";      // time mode(real or live)
			const static String ^MT0W = "MT0W";      // measurement time(msb 32bit)
			const static String ^MT1W = "MT1W";      // measurement time(lsb 32bit)
			const static String ^PDSW = "PDSW";      // peak search
			const static String ^AQSW = "AQSW";      // start measurement
			const static String ^AQEW = "AQEW";      // stop  measurement
			const static String ^CLRW = "CLRW";      // clear measurement data
			const static String ^HCHW = "HCHW";      // change histogram CH number
			const static String ^LISR = "LISR";      // request list data
			const static String ^VER0 = "VER0";      // version1
			const static String ^VER1 = "VER1";      // version2

			const static String ^HIXX = "HI{0:X2}";  // request histogram data block number
			const static String ^LISA = "LISA";      // list data size(answer)

			const static String ^STUW = "STUW";      // request status

											  /* command of CH unit */
			const static String ^ADG = "ADG";        // ADC gain
			const static String ^THR = "THR";        // threshold(ch)
			const static String ^LLD = "LLD";        // energy lower discrimination level(ch)
			const static String ^ULD = "ULD";        // energy upper discrimination level(ch)
			const static String ^OFS = "OFS";        // offset(ch)
			const static String ^IOF = "IOF";        // unuse...
			const static String ^IFG = "IFG";        // unuse...

		public:
			static bool isChCommand(String ^command1, String ^command2);

		};

		/////CH Type Enum/////
		/// <summary>
		/// Summary for CH_TYPE(Enum)
		/// </summary>
		public enum class CH_TYPE : unsigned int
		{
			Common = 0,
			CH1 = 1,
			CH2 = 2,
			CH3 = 3,
			CH4 = 4
		};

		/////data mode Enum/////
	/// <summary>
	/// Summary for DataMode(Enum)
	/// </summary>
		public enum class DataMode : unsigned int
		{
			Histogram = 0,
			List = 1
		};

		/////time mode/////
		/// <summary>
		/// Summary for TimeMode(Enum)
		/// </summary>
		public enum class TimeMode : unsigned int
		{
			Real = 0,
			Live = 1
		};

		/////ADC Gain Enum/////
		/// <summary>
		/// Summary for PdsMode(Enum)
		/// </summary>
		public enum class PdsMode : unsigned int
		{
			Abs = 0,
			Fast = 1
		};

		/////ADC Gain Enum/////
		/// <summary>
		/// Summary for AdcGain(Enum)
		/// </summary>
		public enum class AdcGain : unsigned int
		{
			CH_16K = 0, // 16384ch
			CH_08K = 1, //  8192ch
			CH_04K = 2, //  4096ch
			CH_02K = 3, //  2048ch
			CH_01K = 4, //  1024ch
			CH_512 = 5  //   512ch
		};

		/////Max Class/////
		/// <summary>
		/// Summary for Max
		/// </summary>
		public ref class Max
		{
		public:
			static const int CH = 4;                        // CH count
			static const int HistogramRecieveCount = 32;    // number of times to receive histogram data(per 1ch)
			static const int Resolution = 16384;            // resolution

			static const int ListDataLengthByte = 8;        // list data size(1 unit)

		private:
			static const unsigned int AdcGainEnd = (unsigned int)(AdcGain::CH_512); // end of ADG code

		public:
			static int GetAdgMaxCh(unsigned int uAdg);

		};

		/////Size Class/////
		/// <summary>
		/// Summary for Size
		/// </summary>
		public ref class Size
		{
		public:
			static const int HistogramOneChSize = sizeof(int);		// size(byte) per 1ch
			static const int HistogramOnceCh = 512;					// number of reception channels per reception
			static const int HistogramOnceByte = HistogramOneChSize * HistogramOnceCh;			// one reception size
			static const int HistogramMaxCh = HistogramOnceCh * Max::HistogramRecieveCount;		// receive size of 1CH

			static const int ListDataBlock = 8;		// list data size
		};

	}
} }



